#ifndef _X11_CORE_H_
#define _X11_CORE_H_

#include <X11/Intrinsic.h>

#ifdef __cplusplus
extern "C" {
#endif


    extern WidgetClass coreWidgetClass;
#ifdef __cplusplus
}
#endif
#endif
